@@ -33,11 +33,23 @@
 
 #include <QObject>
 #include <QMap>
+#include <QMargins>
 
 #if OXYGEN_HAVE_X11
 #include <xcb/xcb.h>
 #endif
 
+#if OXYGEN_HAVE_KWAYLAND
+namespace KWayland
+{
+namespace Client
+{
+    class ShadowManager;
+    class ShmPool;
+}
+}
+#endif
+
 namespace Oxygen
 {
 
@@ -118,6 +130,12 @@ namespace Oxygen
         // create pixmap handle from pixmap
         quint32 createPixmap( const QPixmap& );
 
+        //* installs shadow on given widget in a platform independent way
+        bool installShadows( QWidget * );
+
+        //* uninstalls shadow on given widget in a platform independent way
+        void uninstallShadows( QWidget * ) const;
+
         //! install shadow X11 property on given widget
         /*!
         shadow atom and property specification available at
@@ -128,6 +146,18 @@ namespace Oxygen
         //! uninstall shadow X11 property on given widget
         void uninstallX11Shadows( QWidget* ) const;
 
+        //* install shadow on given widget for Wayland
+        bool installWaylandShadows( QWidget * );
+
+        //* uninstall shadow on given widget for Wayland
+        void uninstallWaylandShadows( QWidget* ) const;
+
+        //* initializes the Wayland specific parts
+        void initializeWayland();
+
+        //* gets the shadow margins for the given widget
+        QMargins shadowMargins( QWidget* ) const;
+
         private:
 
         //! helper
@@ -167,6 +197,15 @@ namespace Oxygen
 
         #endif
 
+        #if OXYGEN_HAVE_KWAYLAND
+
+        //* The Wayland shadow manager to create Shadows for Surfaces (QWindow)
+        KWayland::Client::ShadowManager* _shadowManager;
+        //* The Wayland Shared memory pool to share the shadow pixmaps with compositor
+        KWayland::Client::ShmPool* _shmPool;
+
+        #endif
+
     };
 
 }
